package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````B!L``#0```#4H0````0`!30`(``)
M`"@`'0`<``$``'`@D0``()$``""1``#H````Z`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````,D@``#)(```4`````$```
M`0```*2=``"DK0``I*T``*0"``"X`@``!@`````0```"````K)T``*RM``"L
MK0``(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DI)T`
M`*2M``"DK0``7`(``%P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4``_Y#.+SM]ZSI&9B-2S?::<^).W($
M````$`````$```!'3E4```````,````"`````````&$```!K````````````
M``!9````00``````````````"````````````````````#D`````````2@``
M`#@```!D`````````"L```!0````40```#(```!A````9P````,````O````
M```````````C````1@```"T``````````````%(```!)````-@```$T```!>
M````:@```"$````'````"0`````````8`````````#\```!B````3P```#,`
M````````3````&,````U````#0```#H``````````````%H````Q````2```
M`$4````J````````````````````/0```$,````````````````````6````
M#P`````````^````(@```"<```````````````H```!'````-P```#L```!4
M`````````"X```!I````0`````````````````````````!5`````````$(`
M``!7````*`````8````D````2P``````````````````````````````````
M````````````````````````````````````````````````````````````
M$`````````!6````````````````````````````````````%```````````
M````6``````````<`````````&4```!H`````````!\``````````````!D`
M````````9@``````````````&P````X````@````)@````0````,````'@``
M`"P``````````````!T```!.``````````````!3````)0```%P````:````
M`````!<````+````````````````````6P```#`````\````$P```$0```!=
M````````````````````````````````````!0```````````````````#0`
M```````````````````1````````````````````*0```!4`````````$@``
M``````````````````````!?````````````````````8```````````````
M$0```$T````(````"`````&0$`0E0`2`*(``!:"&4(2`@0`""R@$C#B`$D&*
M```(30```$X```!1````50```%8```!?````8````&$`````````8P```&0`
M``!E````9@```&<```!J```````````````!KS3H;L7?'\[>1RUK?YI\+L6;
MMM1DU'QV5#R4(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_+%COEWFZXY)\
M^J%L8)E/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````-`5`````````P`,````
M````L`````````,`&``3`@`````````````2````MP(`````````````$@``
M`&<``````````````!(```#(```````````````2````!0(`````````````
M$@```$\"`````````````!(```">`@`````````````2````?P``````````
M````$@```/("`````````````!(````!```````````````@````L@$`````
M````````$@```.D"`````````````!(````_`@`````````````2````,@,`
M````````````$@```$T!`````````````!(```#.`0`````````````2````
M$```````````````(````,\"`````````````!(````,`@`````````````2
M````O`(`````````````$@`````"`````````````!(```#!````````````
M```2````+```````````````(````+H``````````````!(```"E`0``````
M```````2````P0(`````````````$@```#$!`````````````!8````A`0``
M```````````2````!0,`````````````$@```!`!`````````````!(```#:
M`@`````````````2````V@``````````````$@```.\``````````````!(`
M``#6`0`````````````2`````@0`````````````$@```&(!````````````
M`!(```"Q```````````````1````.`(`````````````$@```#D#````````
M`````!$```#=`0`````````````2````J0(`````````````$@```/8`````
M`````````!(```"Y`0`````````````2````<`(`````````````$@```/@!
M`````````````!(```"7`@`````````````2````E@``````````````$@``
M`"H"`````````````!(```#``0`````````````2````_P``````````````
M$@```+D``````````````!(```!M```````````````2````6P(`````````
M````$@```)X!`````````````!(```"+`@`````````````2````1`$`````
M````````$@```*\``````````````!$```#Q`0`````````````1````%@,`
M````````````$0```-```````````````!(````C`P`````````````1````
MX0``````````````$@```*<``````````````!(````%`0`````````````2
M````B`$`````````````$@```)8!`````````````!(```!\`@``````````
M```2````1@``````````````$@```'$!`````````````!(```!;`0``````
M```````2````QP$`````````````$@```.P!`````````````!(````9`@``
M```````````2````6```````````````(@```%T$``!<L````````!``&0`+
M!```7$H``#P!```2``X`@@0``#!```!8!P``$@`.`%,```#`&```R`(``!(`
M#@""`P``3#(```0````2``X`H`,``(A'``#4`@``$@`.`#,$``!(L```````
M`!``&0"H!```4#(``)`"```2``X`:`0``$BP````````$``9`),#``#@-```
M,````!(`#@"V`P``_#L``*`````2``X`%P0``.!.```$````$0`0`$$$```@
M3```5`$``!(`#@!,!```V#```%@````2``X`5`0``%RP````````$``9`'T$
M``!<L````````!``&0"6!```^#X``#@!```2``X`OP0``)P\``!T````$@`.
M`"8$````L````````!``&`#:`P``$#4``*@!```2``X`CP0``$BP````````
M$``8`+4$``!$L```!````!$`&``L!```B!L````````2``X`=`0``)A+``"(
M````$@`.`"@$````L````````"``&`#P`P``U#X``"0````2``X`Q`,``#`Q
M```<`0``$@`.`.8#``!T30``4`$``!(`#@!<!```7+`````````0`!D`QP0`
M`+@V``!$!0``$@`.``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!A8F]R=`!?7W)E9VES=&5R7V%T
M9F]R:P!?7V%E86)I7W5N=VEN9%]C<'!?<'(P`%]?<W1A8VM?8VAK7V9A:6P`
M<W1R;F-M<`!?7V5N=FER;VX`;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D
M9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M
M9&ER`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!B;V]T7T1Y;F%,;V%D
M97(`4$Q?8W5R<F5N=%]C;VYT97AT`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`
M;65M8VAR`%!E<FQ?<W9?<V5T<'9N`%]?865A8FE?=6YW:6YD7V-P<%]P<C$`
M7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R
M8VAR`'-T<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`;65M8W!Y`%]?=F9P
M<FEN=&9?8VAK`&5X:70`<W1D97)R`&QS965K-C0`<F5A9`!M96UC;7``9V5T
M=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N
M-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E
M<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U
M;@!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U
M;F1U;7``4$Q?;65M;W)Y7W=R87``;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`;&EB
M9V-C7W,N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T
M85]S=&%R=`!?7V)S<U]S=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N
M9%]?`%]?8G-S7V5N9%]?`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'
M0T-?,RXU`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U
M+C,X+C(O87)M=C9L+6QI;G5X+71H<F5A9"UM=6QT:2TV-&EN="]#3U)%````
M```````"``$``@`"``(``0`!``,``0`!``(``0`!``(``0`"``$``0`"``(`
M`@`"``$`!``"``$``0`!``$``0`!``(``@`"``(``0`"``(`!0`"``$``@`"
M``$``@`"``(``@`"``(`!``"``$``@`!``(``@`"``$``@`!``(``@`!``(`
M`@`!``8``P`"``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`8`,``!``
M```@````%&EI#0``!0#4!`````````$``0!T`P``$````"````!5)GD+```#
M`-X$`````````0`#`%8#```0`````````+21E@8```8`Y@0``!````"SD98&
M```$`/$$```0````%&EI#0```@#4!````````*2M```7````J*T``!<```#\
MKP``%P````2P```7````%+```!<````8L```%P```""P```7````)+```!<`
M```HL```%P```"RP```7````,+```!<````XL```%P```#RP```7````1+``
M`!<```#(KP``%0L``,RO```5#```T*\``!43``#4KP``%1D``-BO```3'0``
MW*\``!4>``#@KP``%1\``.2O```5)P``Z*\``!4I``#LKP``%3P``/"O```5
M/0``]*\``!4_``#XKP``%4P``-BN```6`P``W*X``!8$``#@K@``%@4``.2N
M```6!@``Z*X``!8'``#LK@``%@@``/"N```6"0``]*X``!8,``#XK@``%@T`
M`/RN```6#@```*\``!8/```$KP``%A````BO```6$0``#*\``!82```0KP``
M%A0``!2O```6%0``&*\``!86```<KP``%A<``""O```6&```)*\``!8:```H
MKP``%AL``"RO```6'```,*\``!8@```TKP``%B$``#BO```6(@``/*\``!8C
M``!`KP``%B0``$2O```6)0``2*\``!8F``!,KP``%B@``%"O```6*@``5*\`
M`!8K``!8KP``%BP``%RO```6+0``8*\``!8N``!DKP``%B\``&BO```6,```
M;*\``!8Q``!PKP``%C(``'2O```6,P``>*\``!8T``!\KP``%C4``("O```6
M-@``A*\``!8W``"(KP``%C@``(RO```6.0``D*\``!8Z``"4KP``%CX``)BO
M```60```G*\``!9!``"@KP``%D(``*2O```60P``J*\``!9$``"LKP``%D4`
M`+"O```61@``M*\``!9(``"XKP``%DD``+RO```62@``P*\``!9+``#$KP``
M%DP```A`+>E\`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7@F````,:/X@G*C.+@
M^+SE`,:/X@G*C.+8^+SE`,:/X@G*C.+0^+SE`,:/X@G*C.+(^+SE`,:/X@G*
MC.+`^+SE`,:/X@G*C.*X^+SE`,:/X@G*C.*P^+SE`,:/X@G*C.*H^+SE`,:/
MX@G*C.*@^+SE`,:/X@G*C.*8^+SE`,:/X@G*C.*0^+SE`,:/X@G*C.*(^+SE
M`,:/X@G*C.*`^+SE`,:/X@G*C.)X^+SE`,:/X@G*C.)P^+SE`,:/X@G*C.)H
M^+SE`,:/X@G*C.)@^+SE`,:/X@G*C.)8^+SE`,:/X@G*C.)0^+SE`,:/X@G*
MC.)(^+SE`,:/X@G*C.)`^+SE`,:/X@G*C.(X^+SE`,:/X@G*C.(P^+SE`,:/
MX@G*C.(H^+SE`,:/X@G*C.(@^+SE`,:/X@G*C.(8^+SE`,:/X@G*C.(0^+SE
M`,:/X@G*C.((^+SE`,:/X@G*C.(`^+SE`,:/X@G*C.+X][SE`,:/X@G*C.+P
M][SE`,:/X@G*C.+H][SE`,:/X@G*C.+@][SE`,:/X@G*C.+8][SE`,:/X@G*
MC.+0][SE`,:/X@G*C.+(][SE`,:/X@G*C.+`][SE`,:/X@G*C.*X][SE`,:/
MX@G*C.*P][SE`,:/X@G*C.*H][SE`,:/X@G*C.*@][SE`,:/X@G*C.*8][SE
M`,:/X@G*C.*0][SE`,:/X@G*C.*(][SE`,:/X@G*C.*`][SE`,:/X@G*C.)X
M][SE`,:/X@G*C.)P][SE`,:/X@G*C.)H][SE`,:/X@G*C.)@][SE`,:/X@G*
MC.)8][SE`,:/X@G*C.)0][SE`,:/X@G*C.)(][SE`,:/X@G*C.)`][SE`,:/
MX@G*C.(X][SE`,:/X@G*C.(P][SE`,:/X@G*C.(H][SE`,:/X@G*C.(@][SE
M`,:/X@G*C.(8][SE`,:/X@G*C.(0][SE`,:/X@G*C.((][SE`<J@XW!`+>D,
MP$W@R`^,Y5C"G^4HT$WB5#*?Y1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-XA0@
MC>(<`(WB-%*?Y0`PD^4D,(WE`#"@X];__^LD(I_E!5"/X`(@E><<,I_E#""-
MY0,PE><"$*#A`P"@X1`PC>5B#0#K!#*?Y0,PE><`0-/E``!4XT\```IP+QWN
M\#&?Y1P`G>4#,)_G`T"`X@,@DN<$`(#BSC/2Y0<!<.,#,(/CSC/"Y6```(H`
M`:#AH?__ZP`PH.&\(9_E&!"=Y0(@C^``8)+EL,&?Y;!1G^6PX9_E'""=Y0``
MD>4,P(_@!5"/X`[@C^`!`%+C84"#Z`0PC.54``#:!`!!X@S`@^("`8#@!."Q
MY0$`4.$$X*SE^___&@/`@N(`X*#C:%&?Y6@1G^4%4(_@#`"5Y00@H.$`X(WE
M`1"/X`SA@^<)___K``!0XRD```I$49_E(&"-X@50C^`,`)7E3?__ZP!`H.$P
M`9_E!A"@X0``C^#0`P#K``!0XR````H<,9_E`S"/X`P`D^7H_O_K(___ZPPA
MG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB<("]
MZ`'__^O<()_E``!0XP(@C^`,`(+E'P``"A;__^MP+QWNQ#"?Y0,PG^<#,)+G
MKD;#Y:/__^H,`)7EY/[_Z]+__^H(`)7E``!0XP$```K?"P#KV?__ZI0`G^4&
M$*#A``"/X*0#`.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)7G``"/X`,0
MH.$,,(WE-?__ZP3`H..P___J`0"@XUO__^L>___KW)4``!P!``"PE0``_```
M`!0!```D`0``>)8``*R6``"8E@``W#@``-PX``!0E@``F!(``"26``#X-0``
M^)4``&"4``"LE0``()4``.0T```H`0``P#8```"PH.,`X*#C!!"=Y`T@H.$$
M("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN<M___KD/[_ZPB3
M```P`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!EO[_ZO"2`````0``+`"?
MY2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!
M$_\OX4B4``!$E```O)(```0!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.%#
M$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A!)0```"4
M``!LD@``"`$``%@PG^58()_E`S"/X``PT^4"((_@``!3XQ[_+Q$!RJ#C$$`M
MZ0S`3>#X#XSE-#"?Y0,PDN<``%/C`@``"B@PG^4#`)_G^?[_Z\?__^L!(*#C
M&#"?Y0,PC^``(,/E$("]Z+23```PD@``+`$``#B3``!HDP``S?__Z@`````!
MRJ#C\$\MZ0S`3>!`#8SE4"R?Y5`\G^4"((_@`S"2YZ??3>(`$*#A$,"-X@`P
MD^64,HWE`#"@XPP@H.$`0*#C0`"`XH!0@>)`0!#I+C2@X?\\`^(N/(/A#G2@
MX0X\@^'_>`?B"`"`XC;OO^8',(/A!0!0X0#@@N4$0(+E"#""Y0Q`@N40((+B
M[O__&H(_C.(<0)WE>,"=Y00PC>6(,)WE&%"-X@@0C>4%`*#A`Q"@X0R0H.%\
M()WE&+"=Y8"`G>6$<)WEC."=Y1!@G>44H)WE`$"-Y0Q0C>4!``#J!;"@X0!`
MC>4`0*#C`3"@X3S`D.4X$)#E"%"PY71`@.4$0)#E!1`AX`D0(>`$P"S@!A`A
MX`+`+.`*P"S@")"@X0.`H.&A/Z#AC#"#X0$0D>`#$('A!#"=Y0<@H.$``%/A
M#G"@X0M@H.$`X*#C`*"=Y7`0@.7A__\:"!"=Y0Q0G>4`D)'E"#N?Y0@@%>4@
MX)'EJ6V@X0$(D>D0@)'E&*"1Y0,@DN"`8H;A#B"2X(EBAN$,P)'E`F"6X`H@
M*.`K0:#A"R`"X`H@(N`,3X3A`F"6X`M/A.$8()WE*<&@X0#/C.$$`"C@`R"2
MX`D``.`*()+@"``@X`G/C.$``)+@"""5Y0S@).`#()+@!N`.X`3@+N`(()+@
MY@V`X`X@DN#@[8+@$""5Y0,@DN`$()+@9D$LX`!`!.`,0"3@!""2X!A`E>5@
M`:#A`T"4X`S`E.!F02#@#D`$X&9!).#N+8+@!,"<X.)-C.`@P)7E`\"<X&;!
MC.!N82#@`F`&X`!@)N`&P)S@*&"5Y6(AH.$#8);@``"6X&YA(N`$8`;@;F$F
MX.3-C.`&`)#@[&V`X#``E>4#`)#@;@&`X&3A(N`,X`[@`N`NX`X`D.`XX)7E
M;,&@X0/@GN`"()[@9.$LX`;@#N!DX2[@Y@V`X`X@DN#@[8+@0""5Y0,@DN!D
M(8+@9D$LX`!`!.`,0"3@!""2X$A`E>5@`:#A`T"4X`S`E.!F02#@#D`$X&9!
M).#N+8+@!,"<X.)-C.!0P)7E`\"<X&;!C.!N82#@`F`&X`!@)N`&P)S@6&"5
MY6(AH.$#8);@``"6X&YA(N`$8`;@;F$FX.3-C.`&`)#@[&V`X&``E>4#`)#@
M;@&`X&3A(N`,X`[@`N`NX`X`D.!HX)7E;,&@X0/@GN`"()[@9.$LX`;@#N!D
MX2[@Y@V`X`X@DN#@[8+@<""5Y0,@DN!D(8+@9D$LX`!`!.`,0"3@!""2X'A`
ME>5@`:#A`T"4X`S`E.!F02#@#D`$X&9!).#N+8+@!,"<X.)-C."`P)7E`\"<
MX&;!C.!N82#@`F`&X`!@)N`&P)S@Y&V,X(C`E>5B(:#A`\"<X```G.!NP2+@
M!,`,X&[!+.`,`)#@YLV`X)``E>4#,)#@9`$BX`8``.`"`"#@;C&#X``PD^#L
M?8/@F`"5Y2PXG^5F8:#A`P"0X*#@E>4"()#@9`$FX`P`(.``()+@`P">X&0!
M@.#G[8+@J$"5Y6PA)N`'("+@`@"0X&<AH.$#0)3@L'"5Y09`E.!L82+@#F`F
MX.X-@.`&0)3@`V"7X&QAAN"X<)7EX,V$X&Y!(N``0"3@!&"6X&`!H.$#0)?@
M`D"4X,!PE>7L+8;@;F$@X`Q@)N`&8)3@`T"7X&Y!A.#(<)7E;.$@X`+@+N#B
M;8;@#D"4X&(AH.$#X)?@``">X-!PE>5LX2+@!N`NX`[@D.`#`)?@YDV$X-AP
ME>5L`8#@9L$BX`3`+.#D[8[@#`"0X&1!H.$#P)?@`B"<X.!PE>5FP23@#L`L
MX`S`DN`#()?@[@V`X.APE>5F(8+@;F$DX`!@)N#@S8S@!B"2X&`!H.$#8)?@
M!&"6X/!PE>5N02#@#$`DX`1`EN`#8)?@["V"X&YAAN#X4)7E;.$@X`+@+N#B
M383@#N"6X&(AH.$#4)7@`%"5X!AAG>5L`2+@!``@X.3MCN```)7@`V"6X.Y=
M@.!LP8;@9`$BX"!AG>4.`"#@;N&@X2AQG>4``)S@`V"6X&3!+N`"();@!<`L
MX.4-@.`,P)+@`R"7X.!MC.!D(8+@9<$NX#!!G>4`P"S@#,"2X&`!H.$#0)3@
MYBV,X`[@E.!EP2#@.$&=Y0;`+.`,P)[@`^"4X&7ACN!F02#@0%&=Y0)`).#B
MS8S@!.">X&(AH.$#4)7@``"5X&9!(N!(49WE#$`DX`1`D.`#`)7@[.V.X/`U
MG^50<9WE9@&`X&QA(N!N4:#A#F`FX.Y-A.`&8)#@;.&%X0,`E^`"`)#@6'&=
MY>0MAN`$X`[@;&$%X`;@CN$.X)#@`W"7X&0!A>%D807@;,&'X`(``.!@<9WE
M!@"`X>+MCN`,`)#@8B&@X0/`E^`%P)S@9%&"X61A`N!H<9WE#E`%X`90A>'N
M#8#@#%"5X`-PE^!NP8+A;F$"X&1!A^``P`S@<'&=Y0;`C.'@787@!$"<X&`!
MH.$#P)?@`L"<X.4MA.!N08#A;F$`X'AQG>4%0`3@!D"$X0Q`E.`#<)?@9<&`
MX65A`.!NX8?@`L`,X(!QG>4&P(SAXDV$X`[@G.!B(:#A`\"7X`#`G.#D#8[@
M9>&"X65A`N"(<9WE!.`.X`;@CN$,X)[@`W"7X&3!@N%D80+@95&'X`#`#."0
M<9WE!L",X>#MCN`%4)S@8`&@X0/`E^`"P)S@[BV%X&11@.%D80#@F'&=Y0Y0
M!>`&4(7A#%"5X`-PE^!NP8#A;F$`X&1!A^`"P`S@H'&=Y0;`C.'B787@!$"<
MX&(AH.$#P)?@`,"<X.4-A.!N08+A;F$"X*AQG>4%0`3@!D"$X0Q`E.`#<)?@
M9<&"X65A`N!NX8?@`,`,X+!QG>4&P(SAX$V$X`[@G.!@`:#A`\"7X`+`G.#D
M+8[@9>&`X65A`."X<9WE!.`.X`;@CN$,X)[@`W"7X&3!@.%D80#@95&'X`+`
M#.#`<9WE!L",X>+MCN`%4)S@8B&@X0/`E^``P)S@[@V%X&11@N%D80+@#E`%
MX`90A>$,4)7@;L&"X6YA`N``P`S@!L",X0!@H./(<9WEX%V%X`-PE^!D08?@
MT'&=Y6`!H.$$0)S@`\"7X`+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@@>4<
M8('E;F$`X-AQG>4&0(3A#$"4X&7!@.$#<)?@96$`X`+`#.!NX8?@!L",X>!Q
MG>7B383@#L"<X&(AH.'D[8S@`W"7X&7!@N%E80+@``"7X`3`#.#H<9WE!L",
MX0#`G.`#<)?@9`&"X>@RG^5D80+@95&'X`X``.#P<9WE!@"`X>[-C.`%`)#@
M;N&@X0-0E^`"4)7@^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!AN!L
M(2[@`&*=Y0`@(N`"()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4X`-`
MEN#E+8+@$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@&&*=
MY64!(N`.`"#@[LV,X```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.```)3@
M;,&@X0-`EN`"0)3@*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[AAN!E
M(2S@,&*=Y0`@(N`"()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"X`S`
MGN`#X);@9>&.X$!BG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@2&*=
MY60!(N`%`"#@Y<V,X```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.```)[@
M;,&@X0/@EN`"X)[@6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!BG>7@
M78+@9"$LX``@(N`"()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"X`S`
MGN`#X);@9.&.X'!BG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@>&*=
MY64!(N`$`"#@``">X`/@EN#DS8S@9>&.X&1A(N"`4IWE[`V`X`Q@)N!LP:#A
M!N">X`-0E>!D82S@`&`FX`(@E>`&()+@`&"@XXA2G>7@[8[@`S"5X&"ABN`)
M,)/@8`$LX`X`(.!D,8/@`#"3X.XM@N#B/8/@(`"1Y0L@DN!N@8C@&*"!Y1"`
M@>4`,('E"""!Y4P@G^4`P)S@,#"?Y0(@C^`@P('E)&"!Y0,PDN<`()/EE#*=
MY0(@,^``,*#C`0``&J??C>+PC[WHD/O_ZZR1```<`0``F7F"6J'KV6[<O!N/
MUL%BRHR%```!RJ#C\$<MZ0S`3>#@#XSER#"?Y0"`4.(#,(_@*P``"KP@G^4"
M,)/G`)"3Y0``6>,H```*`%#8Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``&@!`
MF>4``%3C#```"@E@H.$%(*#A"!"@X00`H.&1^__K``!0XP(``!H%,-3G/0!3
MXPL```H$0+;E``!4X_/__QH$`*#A\(>]Z`A0H.$!,/7E``!3XST`4Q/[__\:
M"%!%X.;__^H)8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"$"@X>W__^H)
M0*#AZ___ZBB%```8`0```<J@XQ!`+>D,P$W@B`^,Y8P@G^6,,)_E`B"/X'#0
M3>(#,)+G#1"@X0`PD^5L,(WE`#"@XP!`H.%,^__K``!0XP``H!,$```:$#"=
MY0\Z`^(*"E/C`0E3$PH```I(()_E0#"?Y0(@C^`#,)+G`""3Y6PPG>4"(#/@
M`#"@XP<``!IPT(WB$("]Z`(0H.,$`*#A\?K_ZQ`/;^&@`J#A[O__ZB;[_^M`
MA```'`$``/2#```!RJ#C\$`MZ0S`3>!P#XSE8"&?Y6`QG^4"((_@`S"2YWS0
M3>(`4%#B`#"3Y70PC>4`,*#C`@``"@`PU>4``%/C"@``&C0AG^4L,9_E`B"/
MX`,PDN<`()/E=#"=Y0(@,^``,*#C0@``&GS0C>+P@+WHH/K_ZP!@4.+Q__\*
M!@"@X2#[_^L``%#C*P``"A,PT.430(#B+@!3XP(``!H!,-3E``!3X_3__PH3
M,-#E+@!3XR8```H%`*#AS?K_ZP!PH.$$`*#AROK_ZP!PA^`"<(?B!P"@X>KZ
M_^L$0(WE`$"@X9PPG^4'(*#A`A"@XP,PC^``4(WE!OO_ZP0`H.$($(WBK/K_
MZP$`<.,$`*#A`P``"A@PG>4/.@/B`0E3XQ(```JV^O_K!`"@X9GZ_^L&`*#A
M]/K_ZP``4./3__\:!@"@X</Z_^L%`*#AV?K_Z[S__^H!,-3E+@!3X]7__QH"
M,-3E``!3X\3__PK1___JH___Z^O__^K%^O_KD(,``!P!``!<@P``9",```'*
MH.,00"WI#,!-X.@/C.5P3QWN;!"?Y6PPG^4!$(_@`S"1YQ#03>)@`)_E##"-
MY0,@H.$``)_G5#"?Y500G^4``)3G`S"/X`$0C^#4^O_K`,"@XT``G^5`,)_E
M``"?YSP@G^4\$)_E`S"/X```E.<"((_@"!"-Z`$0C^!T^O_K$-"-XA"`O>@$
M@@``$`$``/B"``!$8P``B"(``-""``!\)0``;!H``'0B```!RJ#C\$$MZ0S`
M3>```(SE(``,Y0%PH.$`$9_E`=I-XOPPG^4(T$WB`1"/X`,PD><`8*#A`0J-
MX@0`@.(`,)/E`#"`Y0`PH./8`)_E!("-X@@0H.'0()_E``"/X)GZ_^L`0%#B
M!P``V@A0C>(!,$3B`\"%X`0@7.4``%+C%P``&@``4^,4```:<`\=[IPPG^4'
M(*#A`S"?YP80H.$#`)#G(OK_ZX@@G^5T,)_E`B"/X`$:C>(#,)+G!!"!X@`@
MD^4`,)'E`B`SX``PH.,2```:`=J-X@C0C>+P@;WH`T"@X00@H.$O$*#C"`"@
MX9#Z_^L``%#CX___"G#/'>XT`)_E!#"@X0``G^<((*#A!A"@X0``G.<U^O_K
MX?__ZD[Z_^M,@0``'`$````B``#_#P``[($``,B```!\@0```<J@X_!/+>D,
MP$W@T`^,Y0%`H.$8(I_E&#*?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XP`P
MT>4`4*#A/0!3XP%`@0($`*#A#?K_ZPT0H.$`8*#A!0"@X:;^_^O8<9_E`)!0
MX@=PC^!````*!/K_ZP``5N$W``":P#&?Y0"`G>4#<)?G"(&@X0`PU>4``%/C
M/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#
M`(#@`&"7Y1+Z_^L``%#C"`"&YQ4```H%`*#A`#"7Y0@0D^<!,-#D/0!3XP``
M4Q,`,,'E!@``"@$@@>(!,-#D`A"@X0``4^,]`%,3`3#"Y/G__QH],*#C`2"@
MX0`PP>4!,-3D``!3XP$PXN7[__\:$"&?Y0`QG^4"((_@`S"2YP`@D^4$,)WE
M`B`SX``PH.,W```:#-"-XO"/O>@!D$GB`3#4Y```4^,!,.GE^___&N[__^K(
M,)_E`W"7YP"`E^4`,)CE``!3XR8```H(,*#A!""SY0D0H.$``%+C`9")XOK_
M_QH#$('B`;&@X9@PG^4#,(_@`""3Y0``4N,0```:`2"@XPL`H.$`((/ET?G_
MZP"@4.+5__\*"!"@X0F!H.$+,*#A"""@X??Y_^L`H(?E`#"@XP"0C>4!D(GB
M"3&*YZ'__^H+$*#A"`"@X?'Y_^L``%#C`*"@X0``A^7#__\*"8&@X?'__^H#
MD*#A"+"@X]W__^JZ^?_K'(```!P!``#4?P``&`$```1_```,@```/!"?Y3PP
MG^4!$(_@`S"1YW#/'>X#(*#A"-!-XB@`G^4$,(WE``"?YR`PG^4@$)_E``"<
MYP,PC^`!$(_@"-"-XLKY_^KD?0``$`$``-1^```@7P``9!X```'*H./P0"WI
M#,!-X```C.4!RDSB``",Y3``#.7@()_E`MI-XMPPG^4<T$WB`B"/X`,PDN<"
M&HWB%!"!X@`PD^4`,('E`#"@XZ#Y_^NXP)_EN#"?Y0%*C>(,P(_@$$"$X@$0
MC>@"$*#C!`"@X:`@G^4#,(_@#&"-XJ#Y_^L$`*#A`2J@XP80H.&6^?_K`$!0
MX@!0H+,*``"Z`7"$X@<`H.%R^?_K`%!0X@4```H',*#A!A"@X00@H.$\^?_K
M`#"@XP0PQ>=,()_E.#"?Y0(@C^`"&HWB`S"2YQ00@>(`()/E`#"1Y0(@,^``
M,*#C`P``&@4`H.$"VHWB'-"-XO"`O>A=^?_K:'T``!P!```\'@``&!X```$0
M``#(?```M___Z@'*H./P3RWI#,!-X```C.6H``SE1,*?Y4+=3>)`(I_E!-!-
MX@S`C^``8*#A-`*?Y0(@G.=!/8WB$("-X@%`H.$``(_@"!"@X3PP@^(`()+E
M`""#Y0`@H..U_?_K+Q"@XP!0H.$&`*#AY/C_ZP``4.,2```*\`&?Y080H.$`
M`(_@[?[_ZP8`H.'@(9_ET#&?Y0(@C^!!'8WB`S"2YSP0@>(`()/E`#"1Y0(@
M,^``,*#C:0``&D+=C>($T(WB\(^]Z`0`H.$8^?_KI!&?Y0$0C^`G^?_K`$!0
MXN7__PH`,-3ED)&?Y8"@C>(``%/C"9"/X`1P2N([```*``!5XP0```H$$*#A
M!0"@X4SY_^L``%#C*P``"@0`H.'H^/_K`3!`X@,PA.`#`%3A`+"@X0#`H#,`
M,(0P`1"$,@,``#H(``#J`P!1X0#`P^4"```*`2!SY2\`4N/Y__\*!`"@X=?X
M_^L`L*#A!@"@X=3X_^L+`(#@`0"`X@$*4..]__\J^`"?Y0DPH.$``(_@`2J@
MXP(0H.-!`(WI`$"-Y0<`H.$/^?_K"!"@X0<`H.&U^/_K``!0XP,``!I@,!KE
M#SH#X@()4^,5```*M!"?Y0``H.,!$(_@Y_C_ZP!`4.*E__\*`##4Y0``4^/#
M__\:``!5XQ8```H`,-7E+@!3XP,```J`0)_E`;"@XP1`C^#5___J`3#5Y0``
M4^/J__\*]___Z@$0H.,'`*#AD_C_ZP``4./D__\:4`"?Y0<0H.$``(_@?O[_
MZP<`H.&X^/_KCO__ZCA`G^4!L*#C!$"/X,'__^J^^/_K4'P``!P!```\'0``
M#!T``.1[``#,'```L!P``"`<``#,&P``=!L``%`;```D&P```<J@XQ!`+>D,
MP$W@^`^,Y2\0H.,`0*#A8_C_ZP``4.,!0(`2!`"@X1!`O>B:^/_J`<J@XW!`
M+>D,P$W@``",Y1@`#.5P(9_E`=I-XFPQG^4(T$WB`B"/X`$:C>(#,)+G`&!0
MX@00@>(`,)/E`#"!Y0`PH.,O```*`##6Y0``4^,L```*:?C_ZP$@@.(!"E+C
M`$"@X3@``(H$4(WB!A"@X04`H.%G^/_K`3!$X@,PA>`%`%/A!P``F@`0H.,"
M``#J!0!3X0$0P^4"```*`2!3Y"\`4N/Y__\*+Q"@XP4`H.$Q^/_K``!0XR4`
M``H%`%#A`#"@@P`PP(4%`*#A9OC_Z[P@G^6T,)_E`B"/X`$:C>(#,)+G!!"!
MX@`@D^4`,)'E`B`SX``PH.,B```:`=J-X@C0C>)P@+WHB""?Y7PPG^4"((_@
M`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XQ0``!I@`)_E``"/X`':C>((
MT(WB<$"]Z$?X_^H``*#CWO__ZD0@G^4P,)_E`B"/X`$:C>(#,)+G!!"!X@`@
MD^4`,)'E`B`SX``PH.,@`)\%``"/`.S__PI#^/_KD'D``!P!``#<>```I'@`
M`(`9``!8>```.!D```'*H.-P0"WI#,!-X.@/C.7$))_EQ#2?Y0(@C^#`5)_E
M`S"2Y[QDG^4(T$WB!5"/X``PD^4$,(WE`#"@XP9@C^`-0*#A!!"@X08`H.&>
M_/_K``!0XPX```J,-)_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'_
M_PH$,(/B!""3Y0``4N,$((/D^___&NO__^I49)_E!F"/X`00H.$&`*#AB/S_
MZP``4.,.```*-#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKK___J`&2?Y09@C^`$$*#A!@"@X7+\_^L`
M`%#C#@``"MPSG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P
M@^($()/E``!2XP0@@^3[__\:Z___ZJQCG^4&8(_@!!"@X08`H.%<_/_K``!0
MXPX```J$,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B
M!""3Y0``4N,$((/D^___&NO__^I88Y_E!F"/X`00H.$&`*#A1OS_ZP``4.,.
M```*+#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J!&.?Y09@C^`$$*#A!@"@X3#\_^L``%#C#@``
M"M0RG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E
M``!2XP0@@^3[__\:Z___ZK!BG^4&8(_@!!"@X08`H.$:_/_K``!0XPX```I\
M,I_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``
M4N,$((/D^___&NO__^I<8I_E!F"/X`00H.$&`*#A!/S_ZP``4.,.```*)#*?
MY0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C
M!""#Y/O__QKK___J"&*?Y09@C^`$$*#A!@"@X>[[_^L``%#C#@``"LPQG^4`
M$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@
M@^3[__\:Z___ZK1AG^4&8(_@!!"@X08`H.'8^__K``!0XPX```IT,9_E`!"=
MY0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D
M^___&NO__^I@89_E!F"/X`00H.$&`*#APOO_ZP``4.,.```*'#&?Y0`0G>4#
M,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKK___J#`&?Y000H.$``(_@K?O_ZP`04.("```*^`"?Y0``C^#J_/_K\`"?
MY000H.$``(_@I/O_ZP`04.("```*W`"?Y0``C^#A_/_KU`"?Y000H.$``(_@
MF_O_ZP`04.(2```*P`"?Y0``C^#8_/_KN""?Y60PG^4"((_@`S"2YP`@D^4$
M,)WE`B`SX``PH.,0```:F!"?Y9@`G^4!$(_@``"/X`C0C>)P0+WHR/S_ZH0`
MG^4$$*#A``"/X(+[_^L`$%#BZ?__"G``G^4``(_@O_S_Z^7__^H%]__K]'<`
M`!P!``#@=P``!!D``!@!``"T&```9!@``!@8``#(%P``@!<``,06``#<%@``
MD!8``$06``!P%0``G!4``'`5``",%0``C!4``(@5``"L%```E',``&05``#(
M%```-!4``+@4```!RJ#C!.`MY0S`3>#P#XSE>""?Y7@PG^4"((_@=`"?Y0S0
M3>(#,)+G#1"@X0``C^``,)/E!#"-Y0`PH.-1^__K``!0XP4```H``-#E``!0
MXS``4!,!`*`#``"@$P$`(.(T()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@
M`#"@XP$``!H,T(WB!/"=Y,?V_^NP<@``'`$``!04``!@<@```<J@XP\`+>D$
MX"WE#,!-X/`/C.5(()_E2#"?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XS``
MG^4PP)_E%#"-X@``C^``,(WE#`"0YP(0H.,0()WE``"0Y9?V_^O_`*#CYO;_
MZPQR```<`0``Z'$``"`!````P*#C\$<MZ0'HH.,,P$W@#N!,X`'*3.(``(SE
M#@!<X?O__QHX``[E`A"@XW3AG^4!V$WB<,&?Y1C03>(.X(_@#,">YP%(C>(`
M(*#C`#"@XP#`G.44P(3E`,"@XP`0C>4`@*#AAO;_ZP%@4.(`<,'BQR^@X<<_
M)N`",%/@<S#_Y@(P(^`",%/@`B#"X`-@5N`"<,?@``!7XQ1`A.(W``"Z")&?
MY0Q0C>(`$*#C!B"@X0<PH.$(`*#A`!"-Y7#V_^L!`''C`0!P`S(```H)(*#A
M!1"@X0@`H.$S]O_K`0!PXRD```H'`%#C'P``F@@`0.(`0)7@'```*K2@G^4*
MH(_@`@``Z@%`1.(%`%3A%@``.@@@H.,*$*#A!`"@X?OU_^L``%#C]O__&@5`
M1.`&`)3@Q!^GX'P@G^5L,)_E`B"/X`'(C>(#,)+G%,",X@`@D^4`,)SE`B`S
MX``PH.,0```:`=B-XAC0C>+PA[WH`6A6X@!PQ^(!`'?C`0AV`\G__QH``.#C
M`!"@X>G__^HH`)_E``"/X'S__^L@`)_E``"/X'G__^L\]O_K>'$``!P!```(
M``$`]'$``'AP```L$@``$!(```'*H.,00"WI#,!-X/@/C.7N]?_K$?;_ZP``
M4.,``)`5$("]Z`'*H./P0"WI#,!-X-`/C.4`(9_E`'&?Y0`QG^4"((_@'-!-
MX@,PDN<'<(_@`%"@X0<`H.$0$(WB`#"3Y10PC>4`,*#CD/K_ZP!`4.("```*
M`##4Y0``4^,.```:P""?Y;@PG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,D
M```:!1"@X9P`G^4``(_@'-"-XO!`O>B^^__J!0"@X=WU_^L`8*#A!`"@X=KU
M_^L`8(;@`F"&X@8`H.'Z]?_K:!"?Y6@PG^4!$(_@!B"@X0A`C>4#,(_@!!"-
MY0!0C>4"$*#C`$"@X1/V_^M$()_E+#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@
M`#"@XP00H`$'`*`!W?__"N;U_^NP;P``N!$``!P!``!H;P``6!$``"P0```D
M$```W&X```'*H./P3RWI#,!-X.`.C.6T)I_E_-!-X@(@C^"P0(WB`N"@X03@
MH.&@%I_E(""-Y9S&G^6<)I_E`1"/X`(@D><,P(_@##",XAA@C.*D<(WB`""2
MY?0@C>4`(*#C'`"-Y0<`D^@'`(?H#P"VZ`\`KN@#`);H,,",XIA0C>(#`([H
M!P"<Z`<`A>A,!I_E*("-X@@0H.$``(_@+?K_ZP!@4.("```*`##6Y0``4^,I
M`0`:;_7_ZY+U_^L``%#CB```"@!@D.4``%;CA0``"@8`H.&"]?_K@""@X0&P
M@N(+`*#AHO7_ZP#`UN4`4*#A``!<XPN0H!$D`(T5)`$`"MREG^4*H(_@"R"@
MX0HPH.$"$*#C!0"@X0#`C>6X]?_K"P!9X0D@H"$+(*`Q`C!+X@L00N`!P/;E
M`A"!X@(P0^`"`%'A`;"#(`*P@S```%SC`E"%XNO__QJ(!9_E``"/X`(``.H$
M`+3E``!0XPT```H($*#A]_G_ZP!04.+X__\*`##5Y0``4^/U__\**_K_ZP``
M4./R__\*!0"@X6OU_^L`0%#B#0``&@1`E^0``%3C"@``"@`PU.4``%/CU```
M"@0`H.$=^O_K``!0X_7__PH$`*#A7?7_ZP!`4.+Q__\*!`"@X3[U_^LD4)WE
M`&"@X04`H.$Z]?_K`&"&X`%KAN($8(;B!@"@X5GU_^L`<*#AU#2?Y08@H.$#
M,(_@"#"-Y<@TG^4"$*#C`S"/X`0PC>6\-)_E#%"-Y0,PC^``0(WE;_7_ZP<=
MH.,'`*#AW/3_ZP$`<.,#```:A_7_ZP#`D.41`%SCL```&@@0H.$'`*#A3O7_
MZP!`4.(Q```*=#2?Y2`@G>4"$*#C`R"2YQPPG>4``)+E8"2?Y0`PD^4"((_@
M`'"-Y3CU_^L`4*#C3"2?Y20TG^4"((_@`S"2YP`@D^7T,)WE`B`SX``PH./[
M```:!0"@X?S0C>+PC[WH&_7_ZP!@4.*,```:!`"5Y```4.,)```*"!"@X9;Y
M_^L`,%#B^/__"@`PT^4``%/C\O__&@0`E>0``%#C]?__&@T`H.,3]?_K#9"@
MX]1CG^53P*#C`%"@X0FPH.$&8(_@)`"-Y6[__^HX,)WE#SH#X@$)4^/)__\:
M0%"=Y<;T_^L``%7AQ?__&C@PG>6#.Z#AHSN@X0<-4^/`__\:!@"@X?ST_^L`
M4*#A?`.?Y0@0H.$``(_@</G_ZP`04.)_```*'#"=Y0``D^6>^__K`*!0XGH`
M``H*`*#ARO3_ZP,`4.,`D*#A#```FD`3G^4$`$#B``"*X`$0C^`B]?_K``!0
MXP4``!H$`%GCI0``"@F0BN`%,%GE+P!3XZ$```H0`Y_E"!"@X0``C^!3^?_K
M``!0XP,```H`,-#E,`!3XP``4Q,$```:"@"@X0`0H..\]/_K`(!0XEP``!K8
M$I_EV`*?Y0$0C^```(_@A?K_Z^'T_^O(,I_ER"*?Y0,PC^`$,(WEP#*?Y0(@
MC^"\HI_EO)*?Y;R"G^4(`(WE#""-Y0(0H.,&(*#A!0"@X0!PC>4#,(_@W/3_
MZPJ@C^`)D(_@"("/X`X``.KU]/_K`#"0Y1$`4^,/```:Q_3_ZP#`H.$!0(3B
M`A"@XPHPH.$&(*#A!0"@X8`1C>@0D(WE#$"-Y<GT_^L'':#C!0"@X3;T_^L!
M`'#CZ___"@<`H.%B]/_K-`*?Y040H.$``(_@5?K_ZP4`H.%N_O_K9?__Z@-`
MH.$P___J</3_ZX`@H.$!L(+B[/[_ZB`0G>7`(9_E'#"=Y0(@D><`,)/E``"2
MY>PAG^4"$*#C@!"-Z`(@C^",]/_K4O__ZEK^_^O4(9_E<#&?Y0(@C^`#,)+G
M`""3Y?0PG>4"(#/@`#"@XTX``!H&`*#A_-"-XO!/O>AN]/_J)`"-Y>[^_^H<
M,)WE`*"3Y8'__^K-_?_K`*!1X@"0H.&>__^Z`+"@XPH@4.(`,,KB"`"@X0"P
MC>5E]/_KD!"-X@8@H.,(`*#A'!"-Y2KT_^L&`%#C'!"=Y30``!I(,9_ED""=
MY0,`4N&,__\:M"#1X3@QG^4#`%+AB/__&C(@6>(`,,KB"`"@X0"PC>7(0(WB
M3_3_ZR@@H.,(`*#A!!"@X17T_^LH`%#C(```&@`QG^4`$9_E`S"/X`0PC>7X
M,)_E`1"/X`P0C>4&(*#A`A"@XP4`H.$(0(WE`'"-Y0,PC^#PL,WE8?3_ZYO_
M_^H<,)WE!)"3Y0``6>-9__\*"0"@X1+T_^L#`%#C5?__FJP0G^4$`$#B``")
MX`$0C^!K]/_K``!0XPF@H`%-___J+O3_ZXP`G^4``(_@9_W_ZWQN``!<;@``
MD&\``!P!```(#P``P`\````/``#`#@``H`T``)0.```@`0``@`X``.1K``"$
M#0``Y`T``*@-```0#```4`P``-`+``!T"P``_`T``!P-```D#0``R`T``#`+
M``"@"@``D`L``#!I````0T%#2$4``(`)```(#```)`L``-0*``#`"@```<J@
MXW!`+>D,P$W@Z`^,Y5PBG^5<,I_E`B"/X`,PDN<(T$WB`#"3Y00PC>4`,*#C
M<$\=[@U@H.$\,I_E/`*?Y0,PG^<&$*#A`U"4YP``C^!H,-7E:3#%Y6?X_^L`
M`%#C`@``"@`PT.4Q`%/C90``"J[[_^L(,I_E`S"?YP-0E.<`$I_E!0"@X0,P
MH.,!(*#C`1"/X)'S_^L`4%#B#```"A`@E>7@,9_E`!"2Y0,PG^?8(9_E`P"4
MYP(@C^"-\__K$#"5Y0`0D^4(,)'E`043XU@``!JX$9_E`S"@XP$0G^<!(*#C
M`0"4YZ@1G^4!$(_@>O/_ZP!04.(+```*F`&?Y080H.$``(_@._C_ZP`@4.)`
M```*A#&?Y1`0E>4#,)_G`!"1Y0,`E.=R\__K<#&?Y7`1G^4#,)_G`2"@XP-0
ME.<!$(_@!0"@X57S_^M8(9_E`!"@X0(@C^`%`*#A9?/_ZP`@H.-$,9_E1`&?
MY0,PG^<&$*#A`S"4YP``C^!I(,/E'?C_ZRQ1G^4``%#C!5"/X`!`H.$(`(7E
M$0``"@<=H.,$`*#A+_/_ZP$P@.(1`%#C`0!3$R4``(K\()_EM#"?Y0(@C^`#
M,)+G`""3Y00PG>4"(#/@`#"@XQL``!H(T(WB<("]Z`0`E>6N_?_K``!0XP!`
MH.$(`(7EY___&KP`G^4``(_@F//_ZP$PT.4``%/CFO__"I7__^JD,)_E$""5
MY0,PC^`$,)/E``"2Y0`0D^7D^/_KO/__ZH@PG^4#,)_G`P"4YVWS_^NA___J
M=//_ZW0@G^4`,*#A`B"/X`00DN5H`)_E!""@X0`0D>4``(_@??/_ZR1G```<
M`0``"&@``$P(``#09P``W`D``)QG``"X"0``;&<``(P)``!,!P``+&<``!1G
M```\"0``0`D``-QF``#,!@``,&<``'QE``"<"```G&8```QF``!D9@``5`@`
M``'*H.,P0"WI#,!-X.@/C.4,(9_E##&?Y0(@C^``0*#A!`&?Y0,PDN<,T$WB
M#1"@X0``C^``,)/E!#"-Y0`PH..X]__K`#!0X@H```H`,-/E``!3XS``4Q,!
M,*`#`#"@$P$P(^(``%3C`#"@`P$P`Q(``%/C"@``&K`@G^6D,)_E`B"/X`,P
MDN<`()/E!#"=Y0(@,^``,*#C(```&@S0C>(P@+WH`##4Y0``4^/Q__\*!`"@
MX7[Z_^LO$*#C`%"@X=KR_^L``%#C`5"`$@4`H.$2\__K6!"?Y00@H.,!$(_@
M/O/_ZP``4./B__\:1""?Y3`PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,#
M```:!`"@X0S0C>(P0+WHY_?_Z@KS_^M09```'`$``+`%``#H8P``S`4``'1C
M```!RJ#C$$`MZ0S`3>#X#XSE@`"@X_OR_^L.>Y_M`'N`[0Y[G^T">X#M#GN?
M[01[@.T.>Y_M!GN`[0Y[G^T`(*#C"'N`[0U[G^UX((#E"GN`[0Q[@.T0@+WH
M`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````````
M`````<J@X_!'+>D,P$W@X`^,Y0*0H.$`,*#C`4"@X2@0D.4L()#EB<&!X`$`
M7.$"(-/@`%"@X3`@D.4T$)#ER0^@X0$``"H!()+B`!"AXBPPA>6I/J#A@#&#
MX0(PD^"@'J'@>`"5Y2C`A>4``%#C,#"%Y300A>4X@(4"(0``&C\`6>,Q``#:
M0)!)XBECH.$!<(;B!W.$X`@PH.$$$*#A0$"$X@#@D>4$P)'E"`"1Y0P@D>40
M$('B!`!1X0#@@^4$P(/E"`"#Y0P@@^40,(/B\___&@%`H.$%`*#A`/3_ZP<`
M5.'K__\:!FUFX`:3B>`)(*#A!Q"@X0@`H.&"\O_K>)"%Y?"'O>A`<&#B"0!7
MX0EPH*$X@(7B!!"@X0<@H.$``(C@>/+_ZW@PE>4#,(?@0`!3XW@PA>7PA[T8
M!0"@X0>02>`'0(3@Y?/_Z\O__^H$<*#AY?__Z@'*H./P02WI#,!-X.@/C.5_
M(.#C*#"1Y3!@D>4S?[_FHS&@X3\P`^(!P(/B.("!XC@`7.,!0*#A`%"@X39O
MO^8#(,CG/```V@`0H.-`(&SB#`"(X"GR_^L$`*#ARO/_ZS@@H.,`$*#C"`"@
MX2/R_^L$`*#A\&?$X</S_^L#,-3E!`"@X0`PQ>6R,-3A`3#%Y0`PE.4C-*#A
M`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4'
M,,7E$S#4Y0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PP
MQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%
MY2`PE.4C-*#A$C#%Y2`PE.43,,7E\$&]Z/_Q_^H`$*#C#`"(X#@@;.+L\?_K
MQ___Z@@PG^4#,(_@`#"3Y43R_^HT80``"$`MZ0B`O>@!``(`/@```$$````,
M````00```!$```!!````)P```$$````V````00````,```!!````!@```$$`
M```5````00````\```!!````#@```$$````F````00```!,```!!````*0``
M`$$````"````00```!D```!!````"@```$$````+````00``````````````
M)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS
M.CI005(Z.D)/3U0`````+W!R;V,O<V5L9B]E>&4``"]P<F]C+R5I+R5S`&5X
M90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,`
M`"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$
M14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,
M3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@`````Q````;'-E96L@9F%I;&5D`````')E860@9F%I
M;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`
M````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S
M:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R
M.CI615)324].`````#$N,#8S````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`55-%4@````!54T523D%-10````!414U0
M1$E2`%1-4``O=&UP`````'!E<FQX<VDN8P````!#04-(10``/@```$$````,
M````00```!$```!!````)P```$$````V````00````,```!!````!@```$$`
M```5````00````\```!!````#@```$$````F````00```!,```!!````*0``
M`$$````"````00```!D```!!````"@```$$````+````00``````````````
M@;(!@;"PK`<`````AK(!@;"PJP\`````H+(!@;"PKP<`````@;(!@;"PJ@<`
M````A`(!@;`/L0``````A;(!@;"PKG\`````H(?_?["J"8!@BO]_`0```-"+
M_W^O)K*`3)C_?["PKH`LF?]_L*@;@-29_W^PJQZ`5)O_?["H`X#XF_]_?/__
M?RR=_W^PKP*`<)__?["P`8#`G_]_</__?]2@_W^PL+"`T*#_?VS__W]8H_]_
ML+"H@("C_W]H__]_(*7_?["J`8!<JO]_`(0"@/2J_W]<__]_8*O_?V#__W\<
MK?]_L+"H@#BM_W^PJP:`:*[_?["O/H"XM?]_L*H!@(2X_W^PJ0*`N+G_?["P
MJ(`XNO]_L+"N@(2[_W^PL*R`S+S_?["PL(#8O/]_`0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````^!P``(0<```!
M````2P,```$```!6`P```0```&`#```!````=`,``!T```#\!```#````-`5
M```-````V$X``!D```"DK0``&P````0````:````J*T``!P````$````!```
M`+0!``#U_O]O[`0```4```"(#```!@```-@%```*````-P4```L````0````
M%0`````````#````S*X```(```#@`0``%````!$````7````\!,``!$````8
M$P``$@```-@````3````"````!X````(````^___;P$```C^__]OF!(``/__
M_V\#````\/__;\`1``#Z__]O#@``````````````````````````````````
M``````````````````````"LK0````````````#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<
M%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5
M``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4`
M`-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5````
M````````````````````````````````````````````````````````````
M````````P!@````````$L```"E!!4BYP;0H`````+)```-!/````````D%``
M`)10```@D```V$\``"B0````````#)```!20````````G%(``$=#0SH@*%-5
M4T4@3&EN=7@I(#$S+C(N,2`R,#(T,#4P.2!;<F5V:7-I;VX@8C=A,C8Y-S<S
M,V0Q.6$P.3-C8F1D,&4R,#!F9F-E,#8Y831B8S@Q,ET`03(```!A96%B:0`!
M*`````4V2UH`!@<(`0D!"@(2!!,!%`$5`1<#&`$9`1H"'`$B`40!`"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+D%232YE>'1A8@`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
M```````````````````````````````+`````0````(```!4`0``5`$``!D`
M``````````````$`````````$P````<````"````<`$``'`!```D````````
M```````$`````````"8````'`````@```)0!``"4`0``(```````````````
M!``````````X````!0````(```"T`0``M`$``#@#```&``````````0````$
M````-````/;__V\"````[`0``.P$``#L````!@`````````$````!````#X`
M```+`````@```-@%``#8!0``L`8```<````#````!````!````!&`````P``
M``(```"(#```B`P``#<%``````````````$`````````3@```/___V\"````
MP!$``,`1``#6````!@`````````"`````@```%L```#^__]O`@```)@2``"8
M$@``@`````<````#````!`````````!J````"0````(````8$P``&!,``-@`
M```&``````````0````(````<P````D```!"````\!,``/`3``#@`0``!@``
M`!<````$````"````'P````!````!@```-`5``#0%0``#```````````````
M!`````````!W`````0````8```#<%0``W!4``.0"``````````````0````$
M````@@````$````&````P!@``,`8```8-@`````````````(`````````(@`
M```!````!@```-A.``#83@``"```````````````!`````````".`````0``
M``(```#@3@``X$X``/A!``````````````0`````````E@````$````"````
MV)```-B0``!(```````````````$`````````*$````!``!P@@```""1```@
MD0``Z`````X`````````!`````````"L`````0````(````(D@``")(```0`
M``````````````0`````````M@````X````#````I*T``*2=```$````````
M```````$````!````,(````/`````P```*BM``"HG0``!```````````````
M!`````0```#.````!@````,```"LK0``K)T``"`!```'``````````0````(
M````UP````$````#````S*X``,R>```T`0`````````````$````!````-P`
M```!`````P````"P````H```2```````````````!`````````#B````"```
M``,```!(L```2*```!0```````````````0`````````YP````$````P````
M`````$B@``!6```````````````!`````0```/`````#``!P``````````">
MH```,P```````````````0`````````!`````P``````````````T:`````!
2``````````````$`````````
